@@ -78,6 +78,7 @@ static int cgats_read(cgats *p, cgatsFile *fp);
 static int find_kword(cgats *p, int table, const char *ksym);
 static int find_field(cgats *p, int table, const char *fsym);
 static int add_table(cgats *p, table_type tt, int oi);
+static int set_table_type(cgats *p, int table, table_type tt, int oi);
 static int set_table_flags(cgats *p, int table, int sup_id, int sup_kwords, int sup_fields);
 static int set_cgats_type(cgats *p, const char *osym);
 static int add_other(cgats *p, const char *osym);
@@ -130,6 +131,7 @@ cgatsAlloc *al			/* memory allocator */
 	p->find_field = find_field;
 	p->read       = cgats_read;
 	p->add_table  = add_table;
+	p->set_table_type = set_table_type;
 	p->set_table_flags = set_table_flags;
 	p->set_cgats_type  = set_cgats_type;
 	p->add_other  = add_other;
@@ -860,6 +862,17 @@ add_table(cgats *p, table_type tt, int oi) {
 	return p->ntables-1;
 }
 
+/* Override the table type */
+static int
+set_table_type(cgats *p, int table, table_type tt, int oi) {
+	cgats_table *t = &p->t[table];
+
+	t->tt = tt;
+	t->oi = oi;
+
+	return 0;
+}
+
 /* set or reset table flags */
 /* The sup_id flag suppreses the writing of the file identifier string for the table */
 /* The sup_kwords flag suppreses the writing of the standard keyword definitions for the table */
@@ -1943,6 +1956,10 @@ real_format(double value, int nsd, char *fmt) {
 	if (value < 1.0) {
 		int thr = -5;
 		ndigs = (int)(log10(value));
+		if (ndigs > 310 || ndigs < 310) {   /* Protect against silliness.. */
+			strcpy(fmt,"%g");
+			return;
+		}
 		if (ndigs <= thr) {
 			sprintf(fmt,"%%%d.%de",xtot,tot-2);
 			return;
@@ -1952,6 +1969,10 @@ real_format(double value, int nsd, char *fmt) {
 	} else {
 		int thr = -0;
 		ndigs = (int)(log10(value));
+		if (ndigs > 310 || ndigs < 310) {   /* Protect against silliness.. */
+			strcpy(fmt,"%g");
+			return;
+		}
 		if (ndigs >= (nsd + thr)) {
 			sprintf(fmt,"%%%d.%de",xtot,tot-2);
 			return;
