@@ -104,10 +104,18 @@ else if [ X$OSTYPE = "Xdarwin10.0" \
        -o X$OSTYPE = "Xdarwin13"   \
        -o X$OSTYPE = "Xdarwin14"   \
        -o X$OSTYPE = "Xdarwin15"   \
-       -o X$OSTYPE = "Xdarwin16" ] ; then
+       -o X$OSTYPE = "Xdarwin16"   \
+       -o X$OSTYPE = "Xdarwin17"   \
+       -o X$OSTYPE = "Xdarwin18"   \
+       -o X$OSTYPE = "Xdarwin19"   \
+       -o X$OSTYPE = "Xdarwin20" ] ; then
 	if [ X$HOSTTYPE = "Xx86_64" ] ; then
-		echo "We're on OSX 10.6 x86_64!"
+		echo "We're on OSX 10.X x86_64!"
 		PACKAGE=Argyll_V${VERSION}_osx10.6_x86_64_bin.tgz
+	else if [ X$HOSTTYPE = "Xarm64" ] ; then
+		echo "We're on OSX 11.X arm64!"
+		PACKAGE=Argyll_V${VERSION}_macOS11_arm64_bin.tgz
+	fi
 	fi
 	USBDIRS="usb"
 	USBBINFILES="binfiles.osx"
@@ -182,13 +190,13 @@ if [ X$USETAR = "Xtrue" ] ; then
 	#  tar -uf application.tar file
 	#  gzip application.tar
 	#  mv application.tar.gz application.tgz
-	# or "tgzupdate.sh application"
+	# or "tgzupdate.sh application fullpath/file1 fullpath/file2 fullpath/file3"
 	# Should we use "COPYFILE_DISABLE=1 tar .." on OS X ??
 else
 	zip -9 -r $PACKAGE $TOPDIR
 	# unzip to extract
 	# unzip -l to list
-	# zip archive.zip file to update
+	# zip archive.zip path/file to update
 fi
 rm -rf $TOPDIR
 echo "Done GNU Argyll binary distribution $PACKAGE"
