@@ -2,7 +2,7 @@
  /* Platform isolation convenience functions */
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Author: Graeme W. Gill
  * Date:   28/9/97
@@ -108,121 +108,66 @@
 #ifdef NT
 
 /* wait for and then return the next character from the keyboard */
-/* (If not_interactive, return getchar()) */
+/* (If not_interactive set, wait for next stdin character but discard cr or lf) */
 int next_con_char(void) {
 	int c;
 
 	if (not_interactive) {
 		HANDLE stdinh;
-  		char buf[1];
+  		char buf[10], rv = 0;
 		DWORD bread;
 
 		if ((stdinh = GetStdHandle(STD_INPUT_HANDLE)) == INVALID_HANDLE_VALUE) {
 			return 0;
 		}
 	
-		/* Ignore end of line characters */
+		/* Try and read any end of line characters */
 		for (;;) {
-			if (ReadFile(stdinh, buf, 1, &bread, NULL)
-			 && bread == 1
-			 && buf[0] != '\r' && buf[0] != '\n') { 
-				return buf[0];
+			buf[0] = 0;
+			if (ReadFile(stdinh, buf, 3, &bread, NULL)
+			 && bread >= 1) {
+				rv = buf[0];
+				break;
 			}
 		}
+
+		return rv;
 	}
 
 	c = _getch();
 	return c;
 }
 
-#ifdef NEVER	// Don't need this now.
-
-/* Horrible hack to poll stdin when we're not interactive. */
-/* This has the drawback that the char and returm must be */
-/* written in one operation for the character to be recognised - */
-/* trying to do this manually typically doesn't work unless you are */
-/* very fast and lucky. */
-static int th_read_char(void *pp) {
-	char *rp = (char *)pp;
-	HANDLE stdinh;
-  	char buf[1];
-	DWORD bread;
-
-	if ((stdinh = GetStdHandle(STD_INPUT_HANDLE)) == INVALID_HANDLE_VALUE) {
-		*rp = 0;		/* We've started */
-		return 0;
-	}
-
-	*rp = 0;		/* We've started */
-
-	if (ReadFile(stdinh, buf, 1, &bread, NULL)
-	 && bread == 1
-	 && buf[0] != '\r' && buf[0] != '\n') { 
-		*rp = buf[0];
-	}
-
-	return 0;
-}
-#endif	/* NEVER */
-
 /* If there is one, return the next character from the keyboard, else return 0 */
-/* (If not_interactive, always returns 0) */
+/* (If not_interactive set, return next stdin character if available, but discard cr or lf) */
 int poll_con_char(void) {
 
 	if (not_interactive) {		/* Can't assume that it's the console */
 
-#ifdef NEVER	// Use better approach below.
-		athread *getch_thread = NULL;
-		volatile char c = 0xff;
-	
-		/* This is pretty horrible. The problem is that we can't use */
-		/* any of MSWin's async file read functions, because we */
-		/* have no way of ensuring that the STD_INPUT_HANDLE has been */
-		/* opened with FILE_FLAG_OVERLAPPED. Used a thread instead... */
-		/* ReOpenFile() would in theory fix this, but it's not available in WinXP, only Visa+, */
-		/* and aparently doesn't work on stdin anyway! :-( */
-		if ((getch_thread = new_athread(th_read_char, (char *)&c)) != NULL) {
-			HANDLE stdinh;
-
-			if ((stdinh = GetStdHandle(STD_INPUT_HANDLE)) == INVALID_HANDLE_VALUE) {
-				return 0;
-			}
-
-			/* Wait for the thread to start */
-			while (c == 0xff) {
-				Sleep(10);			/* We just hope 1 msec is enough for the thread to start */
-			}
-			Sleep(10);			/* Give it time to read */
-			CancelIo(stdinh);	/* May not work since ReadFile() is on a different thread ? */
-			getch_thread->del(getch_thread);
-			return c;
-		}
-#else	/* ! NEVER */
 		/* This approach is very flakey from the console, but seems */
 		/* to work reliably when operated progromatically. */
 		HANDLE stdinh;
-		char buf[10] = { 0 }, c;
+		char buf[10] = { 0 };
 		DWORD bread;
+		int rv = 0;
 
 		if ((stdinh = GetStdHandle(STD_INPUT_HANDLE)) == INVALID_HANDLE_VALUE) {
-			return 0;
+			return 0;		
 		}
-//		printf("Waiting\n");
-		if (WaitForSingleObject(stdinh, 1) == WAIT_OBJECT_0) {
-//			printf("stdin signalled\n");
-			
-//			FlushFileBuffers(stdinh);
-//			FlushConsoleInputBuffer(stdinh);
-			if (ReadFile(stdinh, buf, 1, &bread, NULL)) {
-				int i;
-//				fprintf(stderr,"Read %d chars 0x%x 0x%x 0x%x\n",bread,buf[0],buf[1], buf[2]);
-				if (buf[0] != '\r' && buf[0] != '\n')
-					return buf[0];
-				return 0;
+		for (;;) {
+			if (WaitForSingleObject(stdinh, 0) == WAIT_OBJECT_0) {
+				buf[0] = buf[1] = buf[2] = 0;
+				if (ReadFile(stdinh, buf, 3, &bread, NULL)) {
+//					fprintf(stderr,"Read %d chars 0x%x 0x%x 0x%x\n",bread,buf[0],buf[1], buf[2]);
+					rv = buf[0];
+					break;
+				}
 			}
+			rv = 0;
+			break;
 		}
-#endif	/* !NEVER */
-		return 0;
+
+		return rv;
 	}
 
 	/* Assume it's the console */
@@ -234,7 +179,7 @@ int poll_con_char(void) {
 }
 
 /* Suck all characters from the keyboard */
-/* (If not_interactive, does nothing ?) */
+/* (If not_interactive set, discard all pending characters of stdin) */
 void empty_con_chars(void) {
 
 	if (not_interactive) {
@@ -304,6 +249,34 @@ void msec_beep(int delay, int freq, int msec) {
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
+/* Hack to deal with a possibly statically initilized amutex on MSWin. */
+/* We statically initilize the CRITICAL_SECTION with a sentinel */
+/* LockCount value, and if this value is set, use an atomic */
+/* lock to do the initilization before any other operation on it. */
+/* (A more robust trick may be to declare the amutex as a pointer */
+/*  and create it if it is NULL using a InterlockedCompareExchange()) */
+int amutex_chk(CRITICAL_SECTION *lock) {
+
+	if (lock->LockCount == amutex_static_LockCount) {		/* Not initialized */
+		static volatile LONG ilock = 0;
+
+		/* Try ilock */
+		if (InterlockedCompareExchange((LONG **)&ilock, (LONG *)1, (LONG *)0) == 0) {
+			/* We locked it */
+			if (lock->LockCount == amutex_static_LockCount) {	/* Still not inited */
+				InitializeCriticalSection(lock);				/* So we init it */
+			}
+			ilock = 0;		/* We're done */
+		} else {			/* Wait for other thread to finish init */
+			while(ilock != 0) {
+				msec_sleep(1);
+			}
+		}
+	}
+	return 0;
+}
+
+
 int acond_timedwait_imp(HANDLE cond, CRITICAL_SECTION *lock, int msec) {
 	int rv;
 	LeaveCriticalSection(lock);
@@ -341,18 +314,74 @@ int set_normal_priority() {
 
 #undef USE_BEGINTHREAD
 
-/* Wait for the thread to exit. Return the result */
-static int athread_wait(struct _athread *p) {
+/* If reusable, start a stopped thread. NOP if not reusable */
+static void athread_start(
+athread *p
+) {
+	DBG("athread_start called\n");
+	if (!p->reusable)
+		return;
 
-	if (p->finished)
+	/* Signal to the thread that it should start */
+	amutex_lock(p->startm);
+	p->startv = 1;
+	acond_signal(p->startc);
+	amutex_unlock(p->startm);
+}
+
+/* If reusable, wait for the thread to stop. Return the result. NOP if not reusable */
+static int athread_wait_stop(
+athread *p
+) {
+	DBG("athread_wait_stop called\n");
+	if (!p->reusable)
 		return p->result;
 
-	WaitForSingleObject(p->th, INFINITE);
+	/* Wait for thread to stop */
+	amutex_lock(p->stopm);
+	while (p->stopv == 0)
+		acond_wait(p->stopc, p->stopm);
+	p->stopv = 0;
+	amutex_unlock(p->stopm);
 
 	return p->result;
 }
 
-/* Destroy the thread */
+/* Wait for the thread to exit. Return the result */
+static int athread_wait(struct _athread *p) {
+
+	if (p->reusable) {
+		p->dofinish = 1;
+		athread_start(p);	/* Wake thread up to cause it to exit */
+	}
+
+	if (p->joined)
+		return p->result;
+
+	WaitForSingleObject(p->th, INFINITE);
+	p->joined = 1;
+
+	return p->result;
+}
+
+/* Forcefully terminate the thread */
+static void athread_terminate(
+athread *p
+) {
+	DBG("athread_terminate called\n");
+
+	if (p == NULL || p->joined)
+		return;
+
+	if (p->th != NULL) {
+		DBG("athread_del calling TerminateThread()\n");
+		TerminateThread(p->th, (DWORD)-1);
+//		WaitForSingleObject(p->th, INFINITE);	// Don't join in case it doesn't terminate	
+	}
+	p->joined = 1;		/* Skip any join afterwards */
+}
+
+/* Free the thread */
 static void athread_del(
 athread *p
 ) {
@@ -362,13 +391,18 @@ athread *p
 		return;
 
 	if (p->th != NULL) {
-		if (!p->finished) {
-			DBG("athread_del calling TerminateThread() because thread hasn't finished\n");
-			TerminateThread(p->th, (DWORD)-1);		/* But it is worse to leave it hanging around */
-		}
+		if (!p->joined)
+			WaitForSingleObject(p->th, INFINITE);
 		CloseHandle(p->th);
 	}
 
+	if (p->reusable) {
+		acond_del(p->startc);
+		amutex_del(p->startm);
+		acond_del(p->stopc);
+		amutex_del(p->stopm);
+	}
+
 	free(p);
 }
 
@@ -386,18 +420,45 @@ DWORD WINAPI threadproc(
 #endif
 	athread *p = (athread *)lpParameter;
 
-	p->result = p->function(p->context);
-	p->finished = 1;
+	if (p->reusable) {		/* Run over and over */
+		for (;;) {
+
+			/* Wait for client to start us */
+			amutex_lock(p->startm);
+			while (p->startv == 0)
+				acond_wait(p->startc, p->startm);
+			p->startv = 0;
+			amutex_unlock(p->startm);
+
+			if (p->dofinish)
+				break;
+
+			p->result = p->function(p->context);
+
+			if (p->dofinish)
+				break;
+
+			/* Signal to the client that we've stopped */
+			amutex_lock(p->stopm);
+			p->stopv = 1;
+			acond_signal(p->stopc);
+			amutex_unlock(p->stopm);
+		}
+
+	} else {
+		p->result = p->function(p->context);
+	}
+//	p->finished = 1;
 #ifdef USE_BEGINTHREAD
 #else
 	return 0;
 #endif
 }
  
-
-athread *new_athread(
+athread *new_athread_reusable(
 	int (*function)(void *context),
-	void *context
+	void *context,
+	int reusable
 ) {
 	athread *p = NULL;
 
@@ -408,9 +469,23 @@ athread *new_athread(
 		return NULL;
 	}
 
+	p->reusable = reusable;
+	if (p->reusable) {
+		amutex_init(p->startm);
+		p->startv = 0;
+		acond_init(p->startc);
+
+		amutex_init(p->stopm);
+		p->stopv = 0;
+		acond_init(p->stopc);
+	}
+
 	p->function = function;
 	p->context = context;
+	p->start = athread_start;
+	p->wait_stop = athread_wait_stop;
 	p->wait = athread_wait;
+	p->terminate = athread_terminate;
 	p->del = athread_del;
 
 	/* Create a thread */
@@ -423,7 +498,7 @@ athread *new_athread(
 #endif
 		a1loge(g_log, 1, "new_athread: CreateThread failed with %d\n",GetLastError());
 		p->th = NULL;
-		athread_del(p);
+		athread_del(p);		/* Cleanup any resources */
 		return NULL;
 	}
 
@@ -472,6 +547,13 @@ int create_parent_directories(char *path) {
 	return 0;
 }
 
+/* return the number of processors */
+int system_processors() {
+	SYSTEM_INFO sysinfo;
+	GetSystemInfo(&sysinfo);
+	return sysinfo.dwNumberOfProcessors;
+}
+
 #endif /* NT */
 
 
@@ -482,14 +564,14 @@ int create_parent_directories(char *path) {
 #if defined(UNIX)
 
 /* Wait for and return the next character from the keyboard */
-/* (If not_interactive, return getchar()) */
+/* (If not_interactive set, wait for next stdin character but discard cr or lf) */
 int next_con_char(void) {
 	struct pollfd pa[1];		/* Poll array to monitor stdin */
 	struct termios origs, news;
 	char rv = 0;
 
+	/* Configure stdin to be ready with just one character if interactive */
 	if (!not_interactive) {
-		/* Configure stdin to be ready with just one character */
 		if (tcgetattr(STDIN_FILENO, &origs) < 0)
 			a1logw(g_log, "next_con_char: tcgetattr failed with '%s' on stdin", strerror(errno));
 		news = origs;
@@ -500,25 +582,24 @@ int next_con_char(void) {
 			a1logw(g_log, "next_con_char: tcsetattr failed with '%s' on stdin", strerror(errno));
 	}
 
-	/* Wait for stdin to have a character */
+	/* Wait for stdin to have at least one character. */
+	/* If not_interactive set then it may be a character followed by cr and/or lf to flush it */
 	pa[0].fd = STDIN_FILENO;
 	pa[0].events = POLLIN | POLLPRI;
 	pa[0].revents = 0;
 
-	if (poll_x(pa, 1, -1) > 0
+	if (poll_x(pa, 1, -1) > 0					/* wait until there is something */
 	 && (pa[0].revents == POLLIN
-		 || pa[0].revents == POLLPRI)) {
-		char tb[3];
-		if (read(STDIN_FILENO, tb, 1) > 0) {	/* User hit a key */
-			rv = tb[0] ;
+		 || pa[0].revents == POLLPRI)) {		/* Something there */
+		char tb[10];
+		if (read(STDIN_FILENO, tb, 3) > 0) {	/* get it and any return */
+			rv = tb[0];
 		}
 	} else {
-		if (!not_interactive)
-			tcsetattr(STDIN_FILENO, TCSANOW, &origs);
 		a1logw(g_log, "next_con_char: poll on stdin returned unexpected value 0x%x",pa[0].revents);
 	}
 
-	/* Restore stdin */
+	/* Restore stdin if interactive */
 	if (!not_interactive && tcsetattr(STDIN_FILENO, TCSANOW, &origs) < 0) {
 		a1logw(g_log, "next_con_char: tcsetattr failed with '%s' on stdin", strerror(errno));
 	}
@@ -527,14 +608,14 @@ int next_con_char(void) {
 }
 
 /* If here is one, return the next character from the keyboard, else return 0 */
-/* (If not_interactive, always returns 0) */
+/* (If not_interactive set, return next stdin character if available, but discard cr or lf) */
 int poll_con_char(void) {
 	struct pollfd pa[1];		/* Poll array to monitor stdin */
 	struct termios origs, news;
 	char rv = 0;
 
+	/* Configure stdin to be ready with just one character if interactive */
 	if (!not_interactive) {
-		/* Configure stdin to be ready with just one character */
 		if (tcgetattr(STDIN_FILENO, &origs) < 0)
 			a1logw(g_log, "poll_con_char: tcgetattr failed with '%s' on stdin", strerror(errno));
 		news = origs;
@@ -545,33 +626,30 @@ int poll_con_char(void) {
 			a1logw(g_log, "poll_con_char: tcsetattr failed with '%s' on stdin", strerror(errno));
 	}
 
-	/* Wait for stdin to have a character */
+	/* See if stdin has a character */
+	/* If not_interactive set then it may be a character followed by cr and/or lf to flush it */
 	pa[0].fd = STDIN_FILENO;
 	pa[0].events = POLLIN | POLLPRI;
 	pa[0].revents = 0;
 
-	if (poll_x(pa, 1, 0) > 0
+	if (poll_x(pa, 1, 0) > 0					/* don't wait if there is nothing */
 	 && (pa[0].revents == POLLIN
-		 || pa[0].revents == POLLPRI)) {
-		char tb[3];
-		if (read(STDIN_FILENO, tb, 1) > 0) {	/* User hit a key */
-			rv = tb[0] ;
+		 || pa[0].revents == POLLPRI)) {		/* Something is there */
+		char tb[10];
+		if (read(STDIN_FILENO, tb, 3) > 0) {	/* Get it and any return */
+			rv = tb[0];
 		}
 	}
 
-	/* Restore stdin */
+	/* Restore stdin if interactive */
 	if (!not_interactive && tcsetattr(STDIN_FILENO, TCSANOW, &origs) < 0)
 		a1logw(g_log, "poll_con_char: tcsetattr failed with '%s' on stdin", strerror(errno));
 
 	return rv;
 }
 
-/* Suck all characters from the keyboard */
-/* (If not_interactive, does nothing) */
+/* Discard all pending characters from stdin */
 void empty_con_chars(void) {
-	if (not_interactive)
-		return;
-
 	tcflush(STDIN_FILENO, TCIFLUSH);
 }
 
@@ -776,18 +854,76 @@ XBell(..);
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - */
 
-/* Wait for the thread to exit. Return the result */
-static int athread_wait(struct _athread *p) {
+/* If reusable, start a stopped thread. NOP if not reusable */
+static void athread_start(
+athread *p
+) {
+	DBG("athread_start called\n");
+	if (!p->reusable)
+		return;
 
-	if (p->finished)
+	/* Signal to the thread that it should start */
+	amutex_lock(p->startm);
+	p->startv = 1;
+	acond_signal(p->startc);
+	amutex_unlock(p->startm);
+}
+
+/* If reusable, wait for the thread to stop. Return the result. NOP if not reusable */
+static int athread_wait_stop(
+athread *p
+) {
+	DBG("athread_wait_stop called\n");
+	if (!p->reusable)
 		return p->result;
 
-	pthread_join(p->thid, NULL);
+	/* Wait for thread to stop */
+	amutex_lock(p->stopm);
+	while (p->stopv == 0)
+		acond_wait(p->stopc, p->stopm);
+	p->stopv = 0;
+	amutex_unlock(p->stopm);
 
 	return p->result;
 }
 
-/* Destroy the thread */
+/* Wait for the thread to exit. Return the result */
+static int athread_wait(struct _athread *p) {
+	int rv;
+
+	if (p->reusable) {
+		p->dofinish = 1;
+		athread_start(p);	/* Wake thread up to cause it to exit */
+	}
+
+	if (p->joined)
+		return p->result;
+
+    if ((rv = pthread_join(p->thid, NULL)) != 0) 
+		warning("pthread_join of thid %d failed with %d",p->thid,rv);
+	p->joined = 1;
+
+	return p->result;
+}
+
+/* Forcefully terminate the thread */
+static void athread_terminate(
+athread *p
+) {
+	DBG("athread_terminate called\n");
+
+	if (p == NULL || p->joined)
+		return;
+
+	if (p->thid != (pthread_t)0) {
+		DBG("athread_terminate calling pthread_cancel()\n");
+		pthread_cancel(p->thid);
+//	    pthread_join(p->thid, NULL);	// Don't join in case it doesn't terminate
+	}
+	p->joined = 1;		/* Skip any join afterwards */
+}
+
+/* Free up thread resources */
 static void athread_del(
 athread *p
 ) {
@@ -796,10 +932,19 @@ athread *p
 	if (p == NULL)
 		return;
 
-	if (!p->finished) {
-		pthread_cancel(p->thid);
+	if (p->thid != 0 && !p->joined) {
+		int rv;
+	    if ((rv = pthread_join(p->thid, NULL)) != 0) 
+			warning("pthread_join of thid %d failed with %d",p->thid,rv);
 	}
-	pthread_join(p->thid, NULL);
+
+	if (p->reusable) {
+		acond_del(p->startc);
+		amutex_del(p->startm);
+		acond_del(p->stopc);
+		amutex_del(p->stopm);
+	}
+
 	free(p);
 }
 
@@ -814,16 +959,41 @@ static void *threadproc(
 	 objc_registerThreadWithCollector();
 #endif
 
-	p->result = p->function(p->context);
-	p->finished = 1;
+	if (p->reusable) {		/* Run over and over */
+		for (;;) {
+
+			/* Wait for client to start us */
+			amutex_lock(p->startm);
+			while (p->startv == 0)
+				acond_wait(p->startc, p->startm);
+			p->startv = 0;
+			amutex_unlock(p->startm);
+
+			if (p->dofinish)		/* If we've been woken up so we can exit */
+				break;
+
+			p->result = p->function(p->context);
+
+			/* Signal to the client that we've stopped */
+			amutex_lock(p->stopm);
+			p->stopv = 1;
+			acond_signal(p->stopc);
+			amutex_unlock(p->stopm);
+		}
+
+	} else {
+		p->result = p->function(p->context);
+	}
+//	p->finished = 1;
 
 	return 0;
 }
  
 
-athread *new_athread(
+athread *new_athread_reusable(
 	int (*function)(void *context),
-	void *context
+	void *context,
+	int reusable
 ) {
 	int rv;
 	athread *p = NULL;
@@ -835,18 +1005,54 @@ athread *new_athread(
 		return NULL;
 	}
 
+	p->reusable = reusable;
+	if (p->reusable) {
+		amutex_init(p->startm);
+		p->startv = 0;
+		acond_init(p->startc);
+
+		amutex_init(p->stopm);
+		p->stopv = 0;
+		acond_init(p->stopc);
+	}
+
 	p->function = function;
 	p->context = context;
+	p->start = athread_start;
+	p->wait_stop = athread_wait_stop;
 	p->wait = athread_wait;
 	p->del = athread_del;
 
+#if defined(UNIX_APPLE)
+	{
+		pthread_attr_t stackSzAtrbt;
+
+		/* Default stack size is 512K - this is a bit small - raise it to 4MB */
+		if ((rv = pthread_attr_init(&stackSzAtrbt)) != 0
+		 || (rv = pthread_attr_setstacksize(&stackSzAtrbt, 4 * 1024 * 1024)) != 0) {
+			fprintf(stderr,"new_athread: thread_attr_setstacksize failed with %d\n",rv);
+			return NULL;
+		}
+
+		/* Create a thread */
+		rv = pthread_create(&p->thid, &stackSzAtrbt, threadproc, (void *)p);
+		if (rv != 0) {
+			a1loge(g_log, 1, "new_athread: pthread_create failed with %d\n",rv);
+			athread_del(p);
+			return NULL;
+		}
+	}
+#else	/* !APPLE */
+
 	/* Create a thread */
 	rv = pthread_create(&p->thid, NULL, threadproc, (void *)p);
 	if (rv != 0) {
 		a1loge(g_log, 1, "new_athread: pthread_create failed with %d\n",rv);
+		p->thid = 0;
 		athread_del(p);
 		return NULL;
 	}
+#endif /* !APPLE */
 
 	DBG("About to exit new_athread()\n");
 	return p;
@@ -907,6 +1113,38 @@ int create_parent_directories(char *path) {
 	return 0;
 }
 
+#if !defined(UNIX_APPLE) || __MAC_OS_X_VERSION_MAX_ALLOWED >= 1040
+
+/* return the number of processors */
+int system_processors() {
+	return sysconf(_SC_NPROCESSORS_ONLN);
+}
+
+#else	/* OS X < 10.4 code */
+
+/* return the number of processors using BSD code */
+int system_processors() {
+	int mib[4];
+	int numCPU;
+	size_t len = sizeof(numCPU); 
+
+	mib[0] = CTL_HW;
+	mib[1] = HW_AVAILCPU; 
+
+	sysctl(mib, 2, &numCPU, &len, NULL, 0);
+
+	if (numCPU < 1) {
+	    mib[1] = HW_NCPU;
+		sysctl(mib, 2, &numCPU, &len, NULL, 0);
+		if (numCPU < 1)
+			numCPU = 1;
+	}
+
+	return numCPU;
+}
+
+#endif
+
 #endif /* defined(UNIX) */
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - */
@@ -1122,4 +1360,24 @@ int kill_nprocess(char **pname, a1log *log) {
 
 #endif /* UNIX_APPLE || NT */
 
+/* ===================================================================== */
+/* Some compatibility functions */
 
+#if defined(UNIX_APPLE) 
+
+size_t osx_strnlen(const char *string, size_t maxlen) {
+  const char *end = memchr(string, '\0', maxlen);
+  return end ? end - string : maxlen;
+}
+
+char *osx_strndup(const char *s, size_t n) {
+	size_t len = osx_strnlen(s, n);
+	char *buf = malloc(len + 1);
+
+	if (buf == NULL)
+		return NULL;
+	buf[len] = '\0';
+  	return memcpy(buf, s, len);
+}
+
+#endif // APPLE && < 1040
