@@ -1,6 +1,6 @@
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Xrite DTP22 related functions
  *
@@ -16,7 +16,7 @@
 
 /* 
    If you make use of the instrument driver code here, please note
-   that it is the author(s) of the code who take responsibility
+   that it is the author(s) of the code who are responsibility
    for its operation. Any problems or queries regarding driving
    instruments with the Argyll drivers, should be directed to
    the Argyll's author(s), and not to any other party.
@@ -589,12 +589,14 @@ instClamping clamp) {		/* NZ if clamp XYZ/Lab to be +ve */
 		icmClamp3(val->XYZ, val->XYZ);
 	val->loc[0] = '\000';
 	val->mtype = inst_mrt_reflective;
+	val->mcond = inst_mrc_none;
 	val->XYZ_v = 1;
 	val->sp.spec_n = 0;
 	val->duration = 0.0;
 
 	if (p->mode & inst_mode_spectral
-	 || XCALSTD_NEEDED(p->target_calstd, p->native_calstd)) {
+	 || XCALSTD_NEEDED(p->target_calstd, p->native_calstd)
+	 || p->custfilt_en) {
 		int j;
 		char *fmt;
 
@@ -625,6 +627,10 @@ instClamping clamp) {		/* NZ if clamp XYZ/Lab to be +ve */
 	/* Apply any XRGA conversion */
 	ipatch_convert_xrga(val, 1, xcalstd_nonpol, p->target_calstd, p->native_calstd, clamp);
 
+	/* Apply custom filter compensation */
+	if (p->custfilt_en)
+		ipatch_convert_custom_filter(val, 1, &p->custfilt, clamp);
+
 	if (user_trig)
 		return inst_user_trig;
 	return inst_ok;
@@ -1100,6 +1106,42 @@ dtp22_get_set_opt(inst *pp, inst_opt_type m, ...)
 		return inst_ok;
 	}
 
+	if (m == inst_opt_set_custom_filter) {
+		va_list args;
+		xspect *sp = NULL;
+
+		va_start(args, m);
+
+		sp = va_arg(args, xspect *);
+
+		va_end(args);
+
+		if (sp == NULL || sp->spec_n == 0) {
+			p->custfilt_en = 0;
+			p->custfilt.spec_n = 0;
+		} else {
+			p->custfilt_en = 1;
+			p->custfilt = *sp;			/* Struct copy */
+		}
+		return inst_ok;
+	}
+
+	if (m == inst_stat_get_custom_filter) {
+		va_list args;
+		xspect *sp = NULL;
+
+		va_start(args, m);
+		sp = va_arg(args, xspect *);
+		va_end(args);
+
+		if (p->custfilt_en) {
+			*sp = p->custfilt;			/* Struct copy */
+		} else {
+			sp = NULL;
+		}
+		return inst_ok;
+	}
+
 	/* Record the trigger mode */
 	if (m == inst_opt_trig_prog
 	 || m == inst_opt_trig_user
