@@ -1,5 +1,5 @@
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Xrite DTP51 related functions
  *
@@ -15,7 +15,7 @@
 
 /* 
    If you make use of the instrument driver code here, please note
-   that it is the author(s) of the code who take responsibility
+   that it is the author(s) of the code who are responsibility
    for its operation. Any problems or queries regarding driving
    instruments with the Argyll drivers, should be directed to
    the Argyll's author(s), and not to any other party.
@@ -548,6 +548,7 @@ ipatch *vals) {		/* Pointer to array of instrument patch values */
 			}
 		}
 		vals[i].mtype = inst_mrt_reflective;
+		vals[i].mcond = inst_mrc_none;
 		vals[i].XYZ_v = 1;
 		vals[i].sp.spec_n = 0;
 		vals[i].duration = 0.0;
