@@ -2,7 +2,7 @@
  /* Illuminant measurement utility */
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  * Author: Graeme W. Gill
  * Date:   3/10/2001
  *
@@ -20,7 +20,12 @@
 /* and reflective (non-UV filtered) measurement, to measure an illuminant */
 /* spectrum that includes a UV estimate. */
 
-/* Based on spotread.c */
+/* This is documented in the paper: */
+/* "Estimating illuminant U.V. without a U.V. capable instrument", */
+/* Graeme W. Gill, IS&T 19th Color and Imaging Conference Final Program */
+/* and Proceedings, pp. 58-60(3) */ 
+
+/* Code based on spotread.c */
 
 /*
 	TTBD:
@@ -431,17 +436,17 @@ int main(int argc, char *argv[])
 	
 		/* Special debug */
 		strcpy(tnp, "_i.sp");
-		if (read_xspect(&i_sp, NULL, tname) == 0) {
+		if (read_xspect(&i_sp, NULL, NULL, tname) == 0) {
 			rd_i = 1;
 			printf("(Found '%s' file and loaded it)\n",tname);
 		}
 		strcpy(tnp, "_r.sp");
-		if (read_xspect(&r_sp, NULL, tname) == 0) {
+		if (read_xspect(&r_sp, NULL, NULL, tname) == 0) {
 			rd_r = 1;
 			printf("(Found '%s' file and loaded it)\n",tname);
 		}
 		strcpy(tnp, "_p.sp");
-		if (read_xspect(&p_sp, NULL, tname) == 0) {
+		if (read_xspect(&p_sp, NULL, NULL, tname) == 0) {
 			rd_p = 1;
 			/* Should read instrument type from debug_p.sp !! */
 			if (inst_illuminant(&insp, instI1Pro) != 0)		/* Hack !! */
@@ -925,13 +930,13 @@ int main(int argc, char *argv[])
 				i_sp = val.sp;
 				if (tmode && rd_i == 0) {
 					strcpy(tnp, "_i.sp");
-					write_xspect(tname, inst_mrt_emission, &i_sp);
+					write_xspect(tname, inst_mrt_emission, inst_mrc_none, &i_sp);
 				}
 			} else if (c == '2') {	/* Illuminant reflected on paper */
 				r_sp = val.sp;
 				if (tmode && rd_r == 0) {
 					strcpy(tnp, "_r.sp");
-					write_xspect(tname, inst_mrt_emission, &r_sp);
+					write_xspect(tname, inst_mrt_emission, inst_mrc_none, &r_sp);
 				}
 			} else if (c == '3') {	/* Paper reflectance */
 				p_sp = val.sp;
@@ -943,7 +948,7 @@ int main(int argc, char *argv[])
 				if (tmode && rd_p == 0) {
 					/* Should save instrument type/instrument illuminant spectrum !!! */
 					strcpy(tnp, "_p.sp");
-					write_xspect(tname, inst_mrt_reflective, &p_sp);
+					write_xspect(tname, inst_mrt_reflective, inst_mrc_none, &p_sp);
 				}
 			}
 
@@ -1063,14 +1068,14 @@ int main(int argc, char *argv[])
 			bf.r_sp = &r_sp;
 			bf.p_sp = &p_sp;
 
-			if ((bf.pap = new_xsp2cie(icxIT_custom, &i_sp, icxOT_CIE_1931_2, NULL, icSigLabData, icxClamp)) == NULL)
+			if ((bf.pap = new_xsp2cie(icxIT_custom, 0.0, &i_sp, icxOT_CIE_1931_2, NULL, icSigLabData, icxClamp)) == NULL)
 				error("new_xsp2cie pap failed");
 
 			if (bf.pap->set_fwa(bf.pap, &insp, NULL, &p_sp) != 0) 
 				error ("Setting FWA compensation failed");
 
 			/* Setup the equal energy to Lab conversion */
-			if ((bf.ref = new_xsp2cie(icxIT_E, NULL, icxOT_CIE_1931_2, NULL, icSigLabData, icxClamp)) == NULL)
+			if ((bf.ref = new_xsp2cie(icxIT_E, 0.0, NULL, icxOT_CIE_1931_2, NULL, icSigLabData, icxClamp)) == NULL)
 				error("new_xsp2cie ref failed");
 
 			/* Estimate an initial gain match */
@@ -1125,16 +1130,16 @@ int main(int argc, char *argv[])
 				for (i = 0; i < ill.spec_n; i++)
 					ill.spec[i] = aill.spec[i]/nacc;
 				
-				if(write_xspect(outname, inst_mrt_ambient, &ill))
+				if (write_xspect(outname, inst_mrt_ambient, inst_mrc_none, &ill))
 					printf("\nWriting file '%s' failed\n",outname);
 				else
 					printf("\nWriting file '%s' succeeded\n",outname);
 
 				if (tmode) {
 					strcpy(tnp, "_mpir.sp");		// Measured paper under illuminant spectrum
-					write_xspect(tname, inst_mrt_reflective, &bf.srop);
+					write_xspect(tname, inst_mrt_reflective, inst_mrc_none, &bf.srop);
 					strcpy(tnp, "_cpir.sp");		// Computed paper under illuminant spectrum
-					write_xspect(tname, inst_mrt_reflective, &bf.cpsp);
+					write_xspect(tname, inst_mrt_reflective, inst_mrc_none, &bf.cpsp);
 				}
 			}
 
@@ -1154,7 +1159,7 @@ int main(int argc, char *argv[])
 				xspect cpdsp;		/* FWA corrected calculated daylight paper reflectance */
 				
 				/* Setup the referencec comversion */
-				if ((cf.ref = new_xsp2cie(icxIT_E, NULL, icxOT_CIE_1931_2, NULL, icSigLabData, icxClamp)) == NULL)
+				if ((cf.ref = new_xsp2cie(icxIT_E, 0.0, NULL, icxOT_CIE_1931_2, NULL, icSigLabData, icxClamp)) == NULL)
 					error("new_xsp2cie ref failed");
 
 				cf.ill = bf.ill; 
