@@ -2,7 +2,7 @@
 #ifndef SS_IMP_H
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Gretag Spectrolino and Spectroscan related
  * defines and declarations - implementation.
@@ -21,7 +21,7 @@
 
 /* 
    If you make use of the instrument driver code here, please note
-   that it is the author(s) of the code who take responsibility
+   that it is the author(s) of the code who are responsibility
    for its operation. Any problems or queries regarding driving
    instruments with the Argyll drivers, should be directed to
    the Argyll's author(s), and not to any other party.
