@@ -3,7 +3,7 @@
 /* This file is conditionaly #included into usbio.c */
  
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Author: Graeme W. Gill
  * Date:   2006/22/4
@@ -257,6 +257,7 @@ void usb_close_port(icoms *p) {
 
 		/* Workaround for some bugs - reset device on close */
 		if (p->uflags & icomuf_reset_before_close) {
+			a1logd(p->log, 6, "usb_close_port: icomuf_reset_before_close\n");
 			if ((rv = ioctl(p->usbd->fd, USBDEVFS_RESET, NULL)) != 0) {
 				a1logd(p->log, 1, "usb_close_port: reset returned %d\n",rv);
 			}
