@@ -18,7 +18,7 @@
 
 /* Basic idea:
 
-	Given to .ti3 files (or equivalent CGATS files), one containing a
+	Given two .ti3 files (or equivalent CGATS files), one containing a
 	spread of target patch values (XYZ, Lab or spectral), and the
 	other containing the corresponding measured values, a PCS->PCS
 	correction RSPL mapping is created to adjust for any innacuracy
@@ -38,7 +38,7 @@
 		they will lead to out of control regions on the gamut surface.
 		- need output profile to clip changes to gamut surface.
 
-		Refinement feedback could go unstable.
+		Refinement feedback could be unstable.
 		- use a damping factor to improve stability.
 
 	Currently the way out of gamut value are handled is to
@@ -389,10 +389,11 @@ main(int argc, char *argv[]) {
 						tillum = icxIT_F10;
 					} else {	/* Assume it's a filename */
 						inst_meas_type mt;
+						inst_meas_cond mc;
 
 						spec = 1;
 						tillum = icxIT_custom;
-						if (read_xspect(&cust_tillum, &mt, na) != 0)
+						if (read_xspect(&cust_tillum, &mt, &mc, na) != 0)
 							usage("Unable to read target spectrum '%s'",na);
 
 						if (mt != inst_mrt_none
@@ -436,10 +437,11 @@ main(int argc, char *argv[]) {
 					illum = icxIT_F10;
 				} else {	/* Assume it's a filename */
 					inst_meas_type mt;
+					inst_meas_cond mc;
 
 					spec = 1;
 					illum = icxIT_custom;
-					if (read_xspect(&cust_illum, &mt, na) != 0)
+					if (read_xspect(&cust_illum, &mt, &mc, na) != 0)
 						usage("Unable to read custom spectrum '%s'",na);
 
 					if (mt != inst_mrt_none
